@@ -44,7 +44,7 @@ if ($debug) {
 }
 
 $classpath_old = $ENV{CLASSPATH};
-$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.4.0.v20080512.jar:$plugins_dir/org.eclipse.equinox.common_3.4.0.v20080421-2006.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20080604-1400.jar:$plugins_dir/stubs.jar";
+$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.4.0.v20080512.jar:$plugins_dir/org.eclipse.equinox.common_3.4.0.v20080421-2006.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20080604-1400.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar";
 $classpath .= ":$plugin_dir/dstore_extra_server.jar";
 $classpath .= ":$plugin_dir/dstore_core.jar";
 $classpath .= ":$plugin_dir/dstore_miners.jar";
